summaryrefslogtreecommitdiffhomepage
path: root/src/rlgl.h
diff options
context:
space:
mode:
authorraysan5 <[email protected]>2016-10-10 19:42:59 +0200
committerraysan5 <[email protected]>2016-10-10 19:42:59 +0200
commit5fecf5c088122dc409bd209b08627e671cbdc175 (patch)
tree6884d35093f1d3d3cd383908ba8884e9abfbae70 /src/rlgl.h
parentc384b375dfb0651291d8a00bce935e1b5631397d (diff)
downloadraylib-5fecf5c088122dc409bd209b08627e671cbdc175.tar.gz
raylib-5fecf5c088122dc409bd209b08627e671cbdc175.zip
Review UpdateVrTracking() and rlglLoadRenderTexture()
Diffstat (limited to 'src/rlgl.h')
-rw-r--r--src/rlgl.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/rlgl.h b/src/rlgl.h
index 5fc9f8b9..3a47b4c8 100644
--- a/src/rlgl.h
+++ b/src/rlgl.h
@@ -375,7 +375,7 @@ float *MatrixToFloat(Matrix mat);
void InitVrDevice(int vrDevice); // Init VR device
void CloseVrDevice(void); // Close VR device
bool IsVrDeviceReady(void); // Detect if VR device (or simulator) is ready
-void UpdateVrTracking(void); // Update VR tracking (position and orientation)
+void UpdateVrTracking(Camera *camera); // Update VR tracking (position and orientation) and camera
void ToggleVrMode(void); // Enable/Disable VR experience (device or simulator)
// Oculus Rift API for direct access the device (no simulator)